@@ -5,6 +5,7 @@
 #' @importFrom utils head data
 #' @importFrom lazyeval lazy_dots all_dots
 #' @importFrom qlcMatrix sim.strings
+#' @importFrom Matrix as.matrix
 #' @importFrom magrittr %>%
 #' @name scrubr-package
 #' @author Scott Chamberlain \email{myrmecocystus@@gmail.com}
@@ -12,17 +13,3 @@
 #' @docType package
 #' @keywords package
 NULL
-
-#' Sample data.frame number 1
-#'
-#' @name sample_data_1
-#' @docType data
-#' @keywords datasets
-NULL
-
-#' Sample data.frame number 2
-#'
-#' @name sample_data_2
-#' @docType data
-#' @keywords datasets
-NULL
