@@ -47,6 +47,6 @@ test_that("creating date rows data works", {
 
   expect_equal(NCOL(df), 7)
   expect_equal(NCOL(aa), 8)
-  expect_that(any(grepl("date", names(df))), not(is_true()))
+  expect_false(any(grepl("date", names(df))))
   expect_that(any(grepl("date", names(aa))), is_true())
 })
